@@ -11,13 +11,16 @@ logger = logging.getLogger(__name__)
 
 class Reporter:
     def __init__(self, output_path=None, template=None):
+        """ Creates a Reporter instance object. """
         self.output_path = output_path or "scanapi-report.html"
         self.template = template
 
     def write(self, results):
+        """ Part of the Reporter instance that is responsible for writing scanapi-report.html.
+        """
         logger.info("Writing documentation")
 
-        template_path = self.template if self.template else "html.jinja"
+        template_path = self.template if self.template else "report.html"
         has_external_template = True if self.template else False
         context = self._build_context(results)
 
@@ -29,10 +32,14 @@ class Reporter:
         logger.info("\nThe documentation was generated successfully.")
         logger.info(f"It is available at {self.output_path}")
 
-    def _build_context(self, results):
+    @staticmethod
+    def _build_context(results):
+        """ Private method of Reporter returns dict containing keys datetime,
+        project_name, results and session and their corresponding values.
+        """
         return {
             "now": datetime.datetime.now().replace(microsecond=0),
-            "project_name": settings.get("project-name", ""),
+            "project_name": settings.get("project_name", ""),
             "results": results,
             "session": session,
         }
