@@ -4,6 +4,7 @@ from jinja2 import Environment, FileSystemLoader, PackageLoader
 
 
 def render(template_path, context, is_external=False):
+    """ Controller function that handles the Jinga2 rending of the template"""
     loader = _loader(is_external)
     env = Environment(loader=loader)
     env.filters["curlify"] = curlify.to_curl
@@ -13,6 +14,7 @@ def render(template_path, context, is_external=False):
 
 
 def _loader(is_external):
+    """ Private function that either returns Jinga2 FileSystemLoader or the PackageLoader. """
     if is_external:
         return FileSystemLoader(searchpath="./")
 
