@@ -61,7 +61,7 @@ class EndpointNode:
 
     @property
     def path(self):
-        path = self.spec.get(PATH_KEY, "").strip()
+        path = str(self.spec.get(PATH_KEY, "")).strip()
         url = join_urls(self.parent.path, path) if self.parent else path
 
         return self.vars.evaluate(url)
@@ -93,7 +93,10 @@ class EndpointNode:
     def _validate(self):
         if self.is_root:
             return validate_keys(
-                self.spec.keys(), self.ALLOWED_KEYS, self.ROOT_REQUIRED_KEYS, ROOT_SCOPE
+                self.spec.keys(),
+                self.ALLOWED_KEYS,
+                self.ROOT_REQUIRED_KEYS,
+                ROOT_SCOPE,
             )
 
         validate_keys(
