@@ -62,7 +62,7 @@ class RequestNode:
     @property
     def full_url_path(self):
         base_path = self.endpoint.path
-        path = self.spec.get(PATH_KEY, "")
+        path = str(self.spec.get(PATH_KEY, ""))
         full_url = join_urls(base_path, path)
 
         return self.endpoint.vars.evaluate(full_url)
@@ -96,6 +96,10 @@ class RequestNode:
         url = self.full_url_path
         logger.info("Making request %s %s", method, url)
 
+        self.endpoint.vars.update(
+            self.spec.get(VARS_KEY, {}), preevaluate=False,
+        )
+
         response = requests.request(
             method,
             url,
@@ -106,7 +110,9 @@ class RequestNode:
         )
 
         self.endpoint.vars.update(
-            self.spec.get(VARS_KEY, {}), extras={"response": response}, preevaluate=True
+            self.spec.get(VARS_KEY, {}),
+            extras={"response": response},
+            preevaluate=True,
         )
 
         tests_results = self._run_tests()
